@@ -11,8 +11,8 @@ from tqdm import tqdm
 from select import select
 from datetime import datetime
 
-from . import SS3
-from .util import RecursiveDefaultDict, Print
+from . import SS3, __version__
+from .util import RecursiveDefaultDict, Print, VERBOSITY
 
 import webbrowser
 import argparse
@@ -53,6 +53,50 @@ ENCODING = "utf-8"
 BASE_PATH = path.join(path.dirname(__file__), "resources/visual_classifier")
 
 
+def main():
+    """The main function to be called when called from the command-line."""
+    parser = argparse.ArgumentParser(description='PySS3 Live Test Server')
+
+    parser.add_argument('MODEL', help="the model name")
+    parser.add_argument('-ph', '--path', help="the test set path")
+    parser.add_argument(
+        '-l', '--label', choices=["file", "folder"], default="folder",
+        help="indicates where to read category labels from"
+    )
+    parser.add_argument(
+        '-p', '--port', type=int, default=0, help="the server port"
+    )
+    parser.add_argument(
+        '-q', '--quiet', help="quiet mode", action="store_true"
+    )
+    args = parser.parse_args()
+
+    if args.quiet:
+        Print.set_verbosity(VERBOSITY.QUIET)
+
+    Print.warn(
+        'PySS3 Server comes with ABSOLUTELY NO WARRANTY. This is free software,'
+        '\nand you are welcome to redistribute it under certain conditions'
+        '\n(read license.txt for more details)\n', decorator=False
+    )
+
+    try:
+        clf = SS3(name=args.MODEL)
+        clf.load_model()
+    except IOError:
+        Print.error("No such model: '%s'" % args.MODEL)
+        exit()
+
+    Server.set_model(clf)
+    if args.path:
+        Server.set_testset_from_files(args.path, args.label == 'folder')
+
+    try:
+        Server.serve(port=args.port, browser=False, quiet=args.quiet)
+    except IOError:
+        Print.error("Error: port number already in use")
+
+
 def content_type(ext):
     """Given a file extension, return the content type."""
     return CONTET_TYPE[ext] if ext in CONTET_TYPE else CONTET_TYPE["_other_"]
@@ -90,7 +134,7 @@ def get_http_contlength(http_request):
 
 
 class Server:
-    """SS3 HTTP server wrapper."""
+    """SS3's Live Test HTTP server class."""
 
     __port__ = 0  # any (free) port
     __clf__ = None
@@ -115,8 +159,9 @@ class Server:
     def __recvall_body__(sock, data, length):
         """Receive all HTTP message body."""
         body = get_http_body(data)
-        while len(body) < length:
-            body += sock.recv(RECV_BUFFER).decode()
+        while len(body) < length and data:
+            data = sock.recv(RECV_BUFFER).decode()
+            body += data
         return url_decode(body)
 
     @staticmethod
@@ -195,6 +240,7 @@ class Server:
         """Serve the 'get_info' message."""
         clf = Server.__clf__
         Server.__send_as_json__(sock, {
+            "version": __version__,
             "model_name": clf.get_name(),
             "hps": clf.get_hyperparameters(),
             "categories": clf.get_categories() + ["[unknown]"],
@@ -251,10 +297,9 @@ class Server:
                             r[0][0] if r[0][1] else unkwon_cat_i
                             for r in map(
                                 classify,
-                                tqdm(
-                                    fcat.readlines(),
-                                    desc=" Classifying '%s' docs" % cat
-                                )
+                                tqdm(fcat.readlines(),
+                                     desc=" Classifying '%s' docs" % cat,
+                                     disable=Print.is_quiet())
                             )
                         ]
                         n_docs = len(Server.__docs__[cat]["clf_result"])
@@ -276,10 +321,9 @@ class Server:
                     Server.__docs__[cat]["file"] = []
                     Server.__docs__[cat]["clf_result"] = []
 
-                    for file in tqdm(
-                        sorted(listdir(cat_path)),
-                        desc=" Classifying '%s' docs" % cat
-                    ):
+                    for file in tqdm(sorted(listdir(cat_path)),
+                                     desc=" Classifying '%s' docs" % cat,
+                                     disable=Print.is_quiet()):
                         file_path = path.join(cat_path, file)
                         if path.isfile(file_path):
                             Server.__docs__[cat]["path"].append(file_path)
@@ -404,9 +448,8 @@ class Server:
         Server.__port__ = server_socket.getsockname()[1]
 
         Print.info(
-            "PySS3 server started (listening on port %d)"
-            %
-            Server.__port__
+            "Live Test server started (listening on port %d)" % Server.__port__,
+            force_show=True
         )
 
         Print.warn(
@@ -465,7 +508,9 @@ class Server:
             webbrowser.open("http://localhost:%d" % Server.__port__)
 
         if quiet:
-            Print.quiet_begin()
+            Print.verbosity_region_begin(VERBOSITY.QUIET)
+        else:
+            Print.verbosity_region_begin(VERBOSITY.VERBOSE)
 
         Print.info("waiting for requests")
         print()
@@ -496,47 +541,12 @@ class Server:
             Server.__server_socket__ = None
 
             if quiet:
-                Print.quiet_end()
+                Print.verbosity_region_end()
 
 
+# more user-friendly aliases
+Live_Test = Server
+Live_Test.run = Server.serve
+
 if __name__ == "__main__":
-    parser = argparse.ArgumentParser(description='PySS3 Live Test Server')
-
-    parser.add_argument('MODEL', help="the model name")
-    parser.add_argument('-ph', '--path', help="the test set path")
-    parser.add_argument(
-        '-l', '--label', choices=["file", "folder"], default="folder",
-        help="indicates where to read category labels from"
-    )
-    parser.add_argument(
-        '-p', '--port', type=int, default=0, help="the server port"
-    )
-    parser.add_argument(
-        '-q', '--quiet', help="quiet mode", action="store_true"
-    )
-    args = parser.parse_args()
-
-    if args.quiet:
-        Print.quiet_begin()
-
-    Print.warn(
-        'PySS3 Server comes with ABSOLUTELY NO WARRANTY. This is free software,'
-        '\nand you are welcome to redistribute it under certain conditions'
-        '\n(read license.txt for more details)\n', decorator=False
-    )
-
-    try:
-        clf = SS3(name=args.MODEL)
-        clf.load_model()
-    except IOError:
-        Print.error("No such model: '%s'" % args.MODEL)
-        exit()
-
-    Server.set_model(clf)
-    if args.path:
-        Server.set_testset_from_files(args.path, args.label == 'folder')
-
-    try:
-        Server.serve(port=args.port, browser=False, quiet=args.quiet)
-    except IOError:
-        Print.error("Error: port number already in use")
+    main()
